# To install chat-gpt inside your terminal 

```
pip install custom-chat-gpt
```
# Dev commands

```
poetry init
poetry add openai rich typer
poetry shell
poetry install
poetry run chat-gpt
poetry build
poetry publish
```